# coding: utf-8

"""
    Wavefront REST API

    <p>The Wavefront REST API enables you to interact with Wavefront servers using standard REST API tools. You can use the REST API to automate commonly executed operations such as automatically tagging sources.</p><p>When you make REST API calls outside the Wavefront REST API documentation you must add the header \"Authorization: Bearer &lt;&lt;API-TOKEN&gt;&gt;\" to your HTTP requests.</p>  # noqa: E501

    OpenAPI spec version: v2
    Contact: chitimba@wavefront.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import wavefront_api_client
from wavefront_api_client.api.derived_metric_api import DerivedMetricApi  # noqa: E501
from wavefront_api_client.rest import ApiException


class TestDerivedMetricApi(unittest.TestCase):
    """DerivedMetricApi unit test stubs"""

    def setUp(self):
        self.api = wavefront_api_client.api.derived_metric_api.DerivedMetricApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_tag_to_derived_metric(self):
        """Test case for add_tag_to_derived_metric

        Add a tag to a specific Derived Metric  # noqa: E501
        """
        pass

    def test_create_derived_metric(self):
        """Test case for create_derived_metric

        Create a specific derived metric definition  # noqa: E501
        """
        pass

    def test_delete_derived_metric(self):
        """Test case for delete_derived_metric

        Delete a specific derived metric definition  # noqa: E501
        """
        pass

    def test_get_all_derived_metrics(self):
        """Test case for get_all_derived_metrics

        Get all derived metric definitions for a customer  # noqa: E501
        """
        pass

    def test_get_derived_metric(self):
        """Test case for get_derived_metric

        Get a specific registered query  # noqa: E501
        """
        pass

    def test_get_derived_metric_by_version(self):
        """Test case for get_derived_metric_by_version

        Get a specific historical version of a specific derived metric definition  # noqa: E501
        """
        pass

    def test_get_derived_metric_history(self):
        """Test case for get_derived_metric_history

        Get the version history of a specific derived metric definition  # noqa: E501
        """
        pass

    def test_get_derived_metric_tags(self):
        """Test case for get_derived_metric_tags

        Get all tags associated with a specific derived metric definition  # noqa: E501
        """
        pass

    def test_remove_tag_from_derived_metric(self):
        """Test case for remove_tag_from_derived_metric

        Remove a tag from a specific Derived Metric  # noqa: E501
        """
        pass

    def test_set_derived_metric_tags(self):
        """Test case for set_derived_metric_tags

        Set all tags associated with a specific derived metric definition  # noqa: E501
        """
        pass

    def test_undelete_derived_metric(self):
        """Test case for undelete_derived_metric

        Undelete a specific derived metric definition  # noqa: E501
        """
        pass

    def test_update_derived_metric(self):
        """Test case for update_derived_metric

        Update a specific derived metric definition  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Wavefront REST API

    <p>The Wavefront REST API enables you to interact with Wavefront servers using standard REST API tools. You can use the REST API to automate commonly executed operations such as automatically tagging sources.</p><p>When you make REST API calls outside the Wavefront REST API documentation you must add the header \"Authorization: Bearer &lt;&lt;API-TOKEN&gt;&gt;\" to your HTTP requests.</p>  # noqa: E501

    OpenAPI spec version: v2
    Contact: chitimba@wavefront.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from wavefront_api_client.configuration import Configuration


class SearchQuery(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'key': 'str',
        'matching_method': 'str',
        'negated': 'bool',
        'value': 'str',
        'values': 'list[str]'
    }

    attribute_map = {
        'key': 'key',
        'matching_method': 'matchingMethod',
        'negated': 'negated',
        'value': 'value',
        'values': 'values'
    }

    def __init__(self, key=None, matching_method=None, negated=None, value=None, values=None, _configuration=None):  # noqa: E501
        """SearchQuery - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._key = None
        self._matching_method = None
        self._negated = None
        self._value = None
        self._values = None
        self.discriminator = None

        self.key = key
        if matching_method is not None:
            self.matching_method = matching_method
        if negated is not None:
            self.negated = negated
        if value is not None:
            self.value = value
        if values is not None:
            self.values = values

    @property
    def key(self):
        """Gets the key of this SearchQuery.  # noqa: E501

        The entity facet (key) by which to search.  Valid keys are any property keys returned by the JSON representation of the entity.  Examples are 'creatorId', 'name', etc.  The following special key keywords are also valid:  'tags' performs a search on entity tags, 'tagpath' performs a hierarchical search on tags, with  periods (.) as path level separators.  'freetext' performs a free text search across many fields of the entity  # noqa: E501

        :return: The key of this SearchQuery.  # noqa: E501
        :rtype: str
        """
        return self._key

    @key.setter
    def key(self, key):
        """Sets the key of this SearchQuery.

        The entity facet (key) by which to search.  Valid keys are any property keys returned by the JSON representation of the entity.  Examples are 'creatorId', 'name', etc.  The following special key keywords are also valid:  'tags' performs a search on entity tags, 'tagpath' performs a hierarchical search on tags, with  periods (.) as path level separators.  'freetext' performs a free text search across many fields of the entity  # noqa: E501

        :param key: The key of this SearchQuery.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and key is None:
            raise ValueError("Invalid value for `key`, must not be `None`")  # noqa: E501

        self._key = key

    @property
    def matching_method(self):
        """Gets the matching_method of this SearchQuery.  # noqa: E501

        The method by which search matching is performed.  Default: CONTAINS  # noqa: E501

        :return: The matching_method of this SearchQuery.  # noqa: E501
        :rtype: str
        """
        return self._matching_method

    @matching_method.setter
    def matching_method(self, matching_method):
        """Sets the matching_method of this SearchQuery.

        The method by which search matching is performed.  Default: CONTAINS  # noqa: E501

        :param matching_method: The matching_method of this SearchQuery.  # noqa: E501
        :type: str
        """
        allowed_values = ["CONTAINS", "STARTSWITH", "EXACT", "TAGPATH"]  # noqa: E501
        if (self._configuration.client_side_validation and
                matching_method not in allowed_values):
            raise ValueError(
                "Invalid value for `matching_method` ({0}), must be one of {1}"  # noqa: E501
                .format(matching_method, allowed_values)
            )

        self._matching_method = matching_method

    @property
    def negated(self):
        """Gets the negated of this SearchQuery.  # noqa: E501

        The flag to create a NOT operation. Default: false  # noqa: E501

        :return: The negated of this SearchQuery.  # noqa: E501
        :rtype: bool
        """
        return self._negated

    @negated.setter
    def negated(self, negated):
        """Sets the negated of this SearchQuery.

        The flag to create a NOT operation. Default: false  # noqa: E501

        :param negated: The negated of this SearchQuery.  # noqa: E501
        :type: bool
        """

        self._negated = negated

    @property
    def value(self):
        """Gets the value of this SearchQuery.  # noqa: E501

        The entity facet value for which to search. Either value or values field is required. If both are set, values takes precedence.  # noqa: E501

        :return: The value of this SearchQuery.  # noqa: E501
        :rtype: str
        """
        return self._value

    @value.setter
    def value(self, value):
        """Sets the value of this SearchQuery.

        The entity facet value for which to search. Either value or values field is required. If both are set, values takes precedence.  # noqa: E501

        :param value: The value of this SearchQuery.  # noqa: E501
        :type: str
        """

        self._value = value

    @property
    def values(self):
        """Gets the values of this SearchQuery.  # noqa: E501

        The entity facet values for which to search based on OR operation. Either value or values field is required. If both are set, values takes precedence.  # noqa: E501

        :return: The values of this SearchQuery.  # noqa: E501
        :rtype: list[str]
        """
        return self._values

    @values.setter
    def values(self, values):
        """Sets the values of this SearchQuery.

        The entity facet values for which to search based on OR operation. Either value or values field is required. If both are set, values takes precedence.  # noqa: E501

        :param values: The values of this SearchQuery.  # noqa: E501
        :type: list[str]
        """

        self._values = values

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SearchQuery, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SearchQuery):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, SearchQuery):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Wavefront REST API

    <p>The Wavefront REST API enables you to interact with Wavefront servers using standard REST API tools. You can use the REST API to automate commonly executed operations such as automatically tagging sources.</p><p>When you make REST API calls outside the Wavefront REST API documentation you must add the header \"Authorization: Bearer &lt;&lt;API-TOKEN&gt;&gt;\" to your HTTP requests.</p>  # noqa: E501

    OpenAPI spec version: v2
    Contact: chitimba@wavefront.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import wavefront_api_client
from wavefront_api_client.api.monitored_service_api import MonitoredServiceApi  # noqa: E501
from wavefront_api_client.rest import ApiException


class TestMonitoredServiceApi(unittest.TestCase):
    """MonitoredServiceApi unit test stubs"""

    def setUp(self):
        self.api = wavefront_api_client.api.monitored_service_api.MonitoredServiceApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_all_services(self):
        """Test case for get_all_services

        Get all monitored services  # noqa: E501
        """
        pass

    def test_get_service(self):
        """Test case for get_service

        Get a specific application  # noqa: E501
        """
        pass

    def test_get_services_of_application(self):
        """Test case for get_services_of_application

        Get a specific application  # noqa: E501
        """
        pass

    def test_update_service(self):
        """Test case for update_service

        Update a specific service  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Wavefront REST API

    <p>The Wavefront REST API enables you to interact with Wavefront servers using standard REST API tools. You can use the REST API to automate commonly executed operations such as automatically tagging sources.</p><p>When you make REST API calls outside the Wavefront REST API documentation you must add the header \"Authorization: Bearer &lt;&lt;API-TOKEN&gt;&gt;\" to your HTTP requests.</p>  # noqa: E501

    OpenAPI spec version: v2
    Contact: chitimba@wavefront.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from wavefront_api_client.configuration import Configuration


class Stripe(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'end_ms': 'int',
        'image_link': 'str',
        'model': 'str',
        'start_ms': 'int'
    }

    attribute_map = {
        'end_ms': 'endMs',
        'image_link': 'imageLink',
        'model': 'model',
        'start_ms': 'startMs'
    }

    def __init__(self, end_ms=None, image_link=None, model=None, start_ms=None, _configuration=None):  # noqa: E501
        """Stripe - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._end_ms = None
        self._image_link = None
        self._model = None
        self._start_ms = None
        self.discriminator = None

        self.end_ms = end_ms
        self.image_link = image_link
        self.model = model
        self.start_ms = start_ms

    @property
    def end_ms(self):
        """Gets the end_ms of this Stripe.  # noqa: E501

        endMs for this stripe  # noqa: E501

        :return: The end_ms of this Stripe.  # noqa: E501
        :rtype: int
        """
        return self._end_ms

    @end_ms.setter
    def end_ms(self, end_ms):
        """Sets the end_ms of this Stripe.

        endMs for this stripe  # noqa: E501

        :param end_ms: The end_ms of this Stripe.  # noqa: E501
        :type: int
        """
        if self._configuration.client_side_validation and end_ms is None:
            raise ValueError("Invalid value for `end_ms`, must not be `None`")  # noqa: E501

        self._end_ms = end_ms

    @property
    def image_link(self):
        """Gets the image_link of this Stripe.  # noqa: E501

        image link for this stripe  # noqa: E501

        :return: The image_link of this Stripe.  # noqa: E501
        :rtype: str
        """
        return self._image_link

    @image_link.setter
    def image_link(self, image_link):
        """Sets the image_link of this Stripe.

        image link for this stripe  # noqa: E501

        :param image_link: The image_link of this Stripe.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and image_link is None:
            raise ValueError("Invalid value for `image_link`, must not be `None`")  # noqa: E501

        self._image_link = image_link

    @property
    def model(self):
        """Gets the model of this Stripe.  # noqa: E501

        model for this stripe  # noqa: E501

        :return: The model of this Stripe.  # noqa: E501
        :rtype: str
        """
        return self._model

    @model.setter
    def model(self, model):
        """Sets the model of this Stripe.

        model for this stripe  # noqa: E501

        :param model: The model of this Stripe.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and model is None:
            raise ValueError("Invalid value for `model`, must not be `None`")  # noqa: E501

        self._model = model

    @property
    def start_ms(self):
        """Gets the start_ms of this Stripe.  # noqa: E501

        startMs for this stripe  # noqa: E501

        :return: The start_ms of this Stripe.  # noqa: E501
        :rtype: int
        """
        return self._start_ms

    @start_ms.setter
    def start_ms(self, start_ms):
        """Sets the start_ms of this Stripe.

        startMs for this stripe  # noqa: E501

        :param start_ms: The start_ms of this Stripe.  # noqa: E501
        :type: int
        """
        if self._configuration.client_side_validation and start_ms is None:
            raise ValueError("Invalid value for `start_ms`, must not be `None`")  # noqa: E501

        self._start_ms = start_ms

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Stripe, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Stripe):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Stripe):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Wavefront REST API

    <p>The Wavefront REST API enables you to interact with Wavefront servers using standard REST API tools. You can use the REST API to automate commonly executed operations such as automatically tagging sources.</p><p>When you make REST API calls outside the Wavefront REST API documentation you must add the header \"Authorization: Bearer &lt;&lt;API-TOKEN&gt;&gt;\" to your HTTP requests.</p>  # noqa: E501

    OpenAPI spec version: v2
    Contact: chitimba@wavefront.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from wavefront_api_client.configuration import Configuration


class KubernetesComponentStatus(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'description': 'str',
        'name': 'str',
        'status': 'bool'
    }

    attribute_map = {
        'description': 'description',
        'name': 'name',
        'status': 'status'
    }

    def __init__(self, description=None, name=None, status=None, _configuration=None):  # noqa: E501
        """KubernetesComponentStatus - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._description = None
        self._name = None
        self._status = None
        self.discriminator = None

        if description is not None:
            self.description = description
        self.name = name
        if status is not None:
            self.status = status

    @property
    def description(self):
        """Gets the description of this KubernetesComponentStatus.  # noqa: E501

        Description of component status  # noqa: E501

        :return: The description of this KubernetesComponentStatus.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this KubernetesComponentStatus.

        Description of component status  # noqa: E501

        :param description: The description of this KubernetesComponentStatus.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def name(self):
        """Gets the name of this KubernetesComponentStatus.  # noqa: E501

        Name of the component status  # noqa: E501

        :return: The name of this KubernetesComponentStatus.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this KubernetesComponentStatus.

        Name of the component status  # noqa: E501

        :param name: The name of this KubernetesComponentStatus.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def status(self):
        """Gets the status of this KubernetesComponentStatus.  # noqa: E501

        Status value  # noqa: E501

        :return: The status of this KubernetesComponentStatus.  # noqa: E501
        :rtype: bool
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this KubernetesComponentStatus.

        Status value  # noqa: E501

        :param status: The status of this KubernetesComponentStatus.  # noqa: E501
        :type: bool
        """

        self._status = status

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(KubernetesComponentStatus, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, KubernetesComponentStatus):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, KubernetesComponentStatus):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Wavefront REST API

    <p>The Wavefront REST API enables you to interact with Wavefront servers using standard REST API tools. You can use the REST API to automate commonly executed operations such as automatically tagging sources.</p><p>When you make REST API calls outside the Wavefront REST API documentation you must add the header \"Authorization: Bearer &lt;&lt;API-TOKEN&gt;&gt;\" to your HTTP requests.</p>  # noqa: E501

    OpenAPI spec version: v2
    Contact: chitimba@wavefront.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from wavefront_api_client.configuration import Configuration


class Account(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'groups': 'list[str]',
        'identifier': 'str',
        'ingestion_policy_id': 'str',
        'roles': 'list[str]',
        'united_permissions': 'list[str]',
        'united_roles': 'list[str]',
        'user_groups': 'list[str]'
    }

    attribute_map = {
        'groups': 'groups',
        'identifier': 'identifier',
        'ingestion_policy_id': 'ingestionPolicyId',
        'roles': 'roles',
        'united_permissions': 'unitedPermissions',
        'united_roles': 'unitedRoles',
        'user_groups': 'userGroups'
    }

    def __init__(self, groups=None, identifier=None, ingestion_policy_id=None, roles=None, united_permissions=None, united_roles=None, user_groups=None, _configuration=None):  # noqa: E501
        """Account - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._groups = None
        self._identifier = None
        self._ingestion_policy_id = None
        self._roles = None
        self._united_permissions = None
        self._united_roles = None
        self._user_groups = None
        self.discriminator = None

        if groups is not None:
            self.groups = groups
        self.identifier = identifier
        if ingestion_policy_id is not None:
            self.ingestion_policy_id = ingestion_policy_id
        if roles is not None:
            self.roles = roles
        if united_permissions is not None:
            self.united_permissions = united_permissions
        if united_roles is not None:
            self.united_roles = united_roles
        if user_groups is not None:
            self.user_groups = user_groups

    @property
    def groups(self):
        """Gets the groups of this Account.  # noqa: E501

        The list of account's permissions.  # noqa: E501

        :return: The groups of this Account.  # noqa: E501
        :rtype: list[str]
        """
        return self._groups

    @groups.setter
    def groups(self, groups):
        """Sets the groups of this Account.

        The list of account's permissions.  # noqa: E501

        :param groups: The groups of this Account.  # noqa: E501
        :type: list[str]
        """

        self._groups = groups

    @property
    def identifier(self):
        """Gets the identifier of this Account.  # noqa: E501

        The unique identifier of an account.  # noqa: E501

        :return: The identifier of this Account.  # noqa: E501
        :rtype: str
        """
        return self._identifier

    @identifier.setter
    def identifier(self, identifier):
        """Sets the identifier of this Account.

        The unique identifier of an account.  # noqa: E501

        :param identifier: The identifier of this Account.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and identifier is None:
            raise ValueError("Invalid value for `identifier`, must not be `None`")  # noqa: E501

        self._identifier = identifier

    @property
    def ingestion_policy_id(self):
        """Gets the ingestion_policy_id of this Account.  # noqa: E501

        The identifier of the ingestion policy linked with account.  # noqa: E501

        :return: The ingestion_policy_id of this Account.  # noqa: E501
        :rtype: str
        """
        return self._ingestion_policy_id

    @ingestion_policy_id.setter
    def ingestion_policy_id(self, ingestion_policy_id):
        """Sets the ingestion_policy_id of this Account.

        The identifier of the ingestion policy linked with account.  # noqa: E501

        :param ingestion_policy_id: The ingestion_policy_id of this Account.  # noqa: E501
        :type: str
        """

        self._ingestion_policy_id = ingestion_policy_id

    @property
    def roles(self):
        """Gets the roles of this Account.  # noqa: E501

        The list of account's roles.  # noqa: E501

        :return: The roles of this Account.  # noqa: E501
        :rtype: list[str]
        """
        return self._roles

    @roles.setter
    def roles(self, roles):
        """Sets the roles of this Account.

        The list of account's roles.  # noqa: E501

        :param roles: The roles of this Account.  # noqa: E501
        :type: list[str]
        """

        self._roles = roles

    @property
    def united_permissions(self):
        """Gets the united_permissions of this Account.  # noqa: E501

        The list of account's permissions assigned directly or through united roles assigned to it  # noqa: E501

        :return: The united_permissions of this Account.  # noqa: E501
        :rtype: list[str]
        """
        return self._united_permissions

    @united_permissions.setter
    def united_permissions(self, united_permissions):
        """Sets the united_permissions of this Account.

        The list of account's permissions assigned directly or through united roles assigned to it  # noqa: E501

        :param united_permissions: The united_permissions of this Account.  # noqa: E501
        :type: list[str]
        """

        self._united_permissions = united_permissions

    @property
    def united_roles(self):
        """Gets the united_roles of this Account.  # noqa: E501

        The list of account's roles assigned directly or through user groups assigned to it  # noqa: E501

        :return: The united_roles of this Account.  # noqa: E501
        :rtype: list[str]
        """
        return self._united_roles

    @united_roles.setter
    def united_roles(self, united_roles):
        """Sets the united_roles of this Account.

        The list of account's roles assigned directly or through user groups assigned to it  # noqa: E501

        :param united_roles: The united_roles of this Account.  # noqa: E501
        :type: list[str]
        """

        self._united_roles = united_roles

    @property
    def user_groups(self):
        """Gets the user_groups of this Account.  # noqa: E501

        The list of account's user groups.  # noqa: E501

        :return: The user_groups of this Account.  # noqa: E501
        :rtype: list[str]
        """
        return self._user_groups

    @user_groups.setter
    def user_groups(self, user_groups):
        """Sets the user_groups of this Account.

        The list of account's user groups.  # noqa: E501

        :param user_groups: The user_groups of this Account.  # noqa: E501
        :type: list[str]
        """

        self._user_groups = user_groups

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Account, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Account):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Account):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Wavefront REST API

    <p>The Wavefront REST API enables you to interact with Wavefront servers using standard REST API tools. You can use the REST API to automate commonly executed operations such as automatically tagging sources.</p><p>When you make REST API calls outside the Wavefront REST API documentation you must add the header \"Authorization: Bearer &lt;&lt;API-TOKEN&gt;&gt;\" to your HTTP requests.</p>  # noqa: E501

    OpenAPI spec version: v2
    Contact: chitimba@wavefront.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from wavefront_api_client.configuration import Configuration


class Notificant(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'content_type': 'str',
        'created_epoch_millis': 'int',
        'creator_id': 'str',
        'custom_http_headers': 'dict(str, str)',
        'customer_id': 'str',
        'description': 'str',
        'email_subject': 'str',
        'id': 'str',
        'is_html_content': 'bool',
        'method': 'str',
        'recipient': 'str',
        'routes': 'list[AlertRoute]',
        'template': 'str',
        'title': 'str',
        'triggers': 'list[str]',
        'updated_epoch_millis': 'int',
        'updater_id': 'str'
    }

    attribute_map = {
        'content_type': 'contentType',
        'created_epoch_millis': 'createdEpochMillis',
        'creator_id': 'creatorId',
        'custom_http_headers': 'customHttpHeaders',
        'customer_id': 'customerId',
        'description': 'description',
        'email_subject': 'emailSubject',
        'id': 'id',
        'is_html_content': 'isHtmlContent',
        'method': 'method',
        'recipient': 'recipient',
        'routes': 'routes',
        'template': 'template',
        'title': 'title',
        'triggers': 'triggers',
        'updated_epoch_millis': 'updatedEpochMillis',
        'updater_id': 'updaterId'
    }

    def __init__(self, content_type=None, created_epoch_millis=None, creator_id=None, custom_http_headers=None, customer_id=None, description=None, email_subject=None, id=None, is_html_content=None, method=None, recipient=None, routes=None, template=None, title=None, triggers=None, updated_epoch_millis=None, updater_id=None, _configuration=None):  # noqa: E501
        """Notificant - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._content_type = None
        self._created_epoch_millis = None
        self._creator_id = None
        self._custom_http_headers = None
        self._customer_id = None
        self._description = None
        self._email_subject = None
        self._id = None
        self._is_html_content = None
        self._method = None
        self._recipient = None
        self._routes = None
        self._template = None
        self._title = None
        self._triggers = None
        self._updated_epoch_millis = None
        self._updater_id = None
        self.discriminator = None

        if content_type is not None:
            self.content_type = content_type
        if created_epoch_millis is not None:
            self.created_epoch_millis = created_epoch_millis
        if creator_id is not None:
            self.creator_id = creator_id
        if custom_http_headers is not None:
            self.custom_http_headers = custom_http_headers
        if customer_id is not None:
            self.customer_id = customer_id
        self.description = description
        if email_subject is not None:
            self.email_subject = email_subject
        if id is not None:
            self.id = id
        if is_html_content is not None:
            self.is_html_content = is_html_content
        self.method = method
        self.recipient = recipient
        if routes is not None:
            self.routes = routes
        self.template = template
        self.title = title
        self.triggers = triggers
        if updated_epoch_millis is not None:
            self.updated_epoch_millis = updated_epoch_millis
        if updater_id is not None:
            self.updater_id = updater_id

    @property
    def content_type(self):
        """Gets the content_type of this Notificant.  # noqa: E501

        The value of the Content-Type header of the webhook POST request.  # noqa: E501

        :return: The content_type of this Notificant.  # noqa: E501
        :rtype: str
        """
        return self._content_type

    @content_type.setter
    def content_type(self, content_type):
        """Sets the content_type of this Notificant.

        The value of the Content-Type header of the webhook POST request.  # noqa: E501

        :param content_type: The content_type of this Notificant.  # noqa: E501
        :type: str
        """
        allowed_values = ["application/json", "text/html", "text/plain", "application/x-www-form-urlencoded", ""]  # noqa: E501
        if (self._configuration.client_side_validation and
                content_type not in allowed_values):
            raise ValueError(
                "Invalid value for `content_type` ({0}), must be one of {1}"  # noqa: E501
                .format(content_type, allowed_values)
            )

        self._content_type = content_type

    @property
    def created_epoch_millis(self):
        """Gets the created_epoch_millis of this Notificant.  # noqa: E501


        :return: The created_epoch_millis of this Notificant.  # noqa: E501
        :rtype: int
        """
        return self._created_epoch_millis

    @created_epoch_millis.setter
    def created_epoch_millis(self, created_epoch_millis):
        """Sets the created_epoch_millis of this Notificant.


        :param created_epoch_millis: The created_epoch_millis of this Notificant.  # noqa: E501
        :type: int
        """

        self._created_epoch_millis = created_epoch_millis

    @property
    def creator_id(self):
        """Gets the creator_id of this Notificant.  # noqa: E501


        :return: The creator_id of this Notificant.  # noqa: E501
        :rtype: str
        """
        return self._creator_id

    @creator_id.setter
    def creator_id(self, creator_id):
        """Sets the creator_id of this Notificant.


        :param creator_id: The creator_id of this Notificant.  # noqa: E501
        :type: str
        """

        self._creator_id = creator_id

    @property
    def custom_http_headers(self):
        """Gets the custom_http_headers of this Notificant.  # noqa: E501

        A string->string map specifying the custom HTTP header key / value pairs that will be sent in the requests of this web hook  # noqa: E501

        :return: The custom_http_headers of this Notificant.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._custom_http_headers

    @custom_http_headers.setter
    def custom_http_headers(self, custom_http_headers):
        """Sets the custom_http_headers of this Notificant.

        A string->string map specifying the custom HTTP header key / value pairs that will be sent in the requests of this web hook  # noqa: E501

        :param custom_http_headers: The custom_http_headers of this Notificant.  # noqa: E501
        :type: dict(str, str)
        """

        self._custom_http_headers = custom_http_headers

    @property
    def customer_id(self):
        """Gets the customer_id of this Notificant.  # noqa: E501


        :return: The customer_id of this Notificant.  # noqa: E501
        :rtype: str
        """
        return self._customer_id

    @customer_id.setter
    def customer_id(self, customer_id):
        """Sets the customer_id of this Notificant.


        :param customer_id: The customer_id of this Notificant.  # noqa: E501
        :type: str
        """

        self._customer_id = customer_id

    @property
    def description(self):
        """Gets the description of this Notificant.  # noqa: E501

        Description  # noqa: E501

        :return: The description of this Notificant.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this Notificant.

        Description  # noqa: E501

        :param description: The description of this Notificant.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and description is None:
            raise ValueError("Invalid value for `description`, must not be `None`")  # noqa: E501

        self._description = description

    @property
    def email_subject(self):
        """Gets the email_subject of this Notificant.  # noqa: E501

        The subject title of an email notification target  # noqa: E501

        :return: The email_subject of this Notificant.  # noqa: E501
        :rtype: str
        """
        return self._email_subject

    @email_subject.setter
    def email_subject(self, email_subject):
        """Sets the email_subject of this Notificant.

        The subject title of an email notification target  # noqa: E501

        :param email_subject: The email_subject of this Notificant.  # noqa: E501
        :type: str
        """

        self._email_subject = email_subject

    @property
    def id(self):
        """Gets the id of this Notificant.  # noqa: E501


        :return: The id of this Notificant.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Notificant.


        :param id: The id of this Notificant.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def is_html_content(self):
        """Gets the is_html_content of this Notificant.  # noqa: E501

        Determine whether the email alert target content is sent as html or text.  # noqa: E501

        :return: The is_html_content of this Notificant.  # noqa: E501
        :rtype: bool
        """
        return self._is_html_content

    @is_html_content.setter
    def is_html_content(self, is_html_content):
        """Sets the is_html_content of this Notificant.

        Determine whether the email alert target content is sent as html or text.  # noqa: E501

        :param is_html_content: The is_html_content of this Notificant.  # noqa: E501
        :type: bool
        """

        self._is_html_content = is_html_content

    @property
    def method(self):
        """Gets the method of this Notificant.  # noqa: E501

        The notification method used for notification target.  # noqa: E501

        :return: The method of this Notificant.  # noqa: E501
        :rtype: str
        """
        return self._method

    @method.setter
    def method(self, method):
        """Sets the method of this Notificant.

        The notification method used for notification target.  # noqa: E501

        :param method: The method of this Notificant.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and method is None:
            raise ValueError("Invalid value for `method`, must not be `None`")  # noqa: E501
        allowed_values = ["WEBHOOK", "EMAIL", "PAGERDUTY"]  # noqa: E501
        if (self._configuration.client_side_validation and
                method not in allowed_values):
            raise ValueError(
                "Invalid value for `method` ({0}), must be one of {1}"  # noqa: E501
                .format(method, allowed_values)
            )

        self._method = method

    @property
    def recipient(self):
        """Gets the recipient of this Notificant.  # noqa: E501

        The end point for the notification target.EMAIL: email address.  PAGERDUTY: PagerDuty routing Key.  WEBHOOK: URL end point  # noqa: E501

        :return: The recipient of this Notificant.  # noqa: E501
        :rtype: str
        """
        return self._recipient

    @recipient.setter
    def recipient(self, recipient):
        """Sets the recipient of this Notificant.

        The end point for the notification target.EMAIL: email address.  PAGERDUTY: PagerDuty routing Key.  WEBHOOK: URL end point  # noqa: E501

        :param recipient: The recipient of this Notificant.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and recipient is None:
            raise ValueError("Invalid value for `recipient`, must not be `None`")  # noqa: E501

        self._recipient = recipient

    @property
    def routes(self):
        """Gets the routes of this Notificant.  # noqa: E501

        List of routing targets that this notificant will notify.  # noqa: E501

        :return: The routes of this Notificant.  # noqa: E501
        :rtype: list[AlertRoute]
        """
        return self._routes

    @routes.setter
    def routes(self, routes):
        """Sets the routes of this Notificant.

        List of routing targets that this notificant will notify.  # noqa: E501

        :param routes: The routes of this Notificant.  # noqa: E501
        :type: list[AlertRoute]
        """

        self._routes = routes

    @property
    def template(self):
        """Gets the template of this Notificant.  # noqa: E501

        A mustache template that will form the body of the POST request, email and summary of the PagerDuty.  # noqa: E501

        :return: The template of this Notificant.  # noqa: E501
        :rtype: str
        """
        return self._template

    @template.setter
    def template(self, template):
        """Sets the template of this Notificant.

        A mustache template that will form the body of the POST request, email and summary of the PagerDuty.  # noqa: E501

        :param template: The template of this Notificant.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and template is None:
            raise ValueError("Invalid value for `template`, must not be `None`")  # noqa: E501

        self._template = template

    @property
    def title(self):
        """Gets the title of this Notificant.  # noqa: E501

        Title  # noqa: E501

        :return: The title of this Notificant.  # noqa: E501
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """Sets the title of this Notificant.

        Title  # noqa: E501

        :param title: The title of this Notificant.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and title is None:
            raise ValueError("Invalid value for `title`, must not be `None`")  # noqa: E501

        self._title = title

    @property
    def triggers(self):
        """Gets the triggers of this Notificant.  # noqa: E501

        A list of occurrences on which this webhook will be fired.  Valid values are ALERT_OPENED, ALERT_UPDATED, ALERT_RESOLVED, ALERT_MAINTENANCE, ALERT_SNOOZED  # noqa: E501

        :return: The triggers of this Notificant.  # noqa: E501
        :rtype: list[str]
        """
        return self._triggers

    @triggers.setter
    def triggers(self, triggers):
        """Sets the triggers of this Notificant.

        A list of occurrences on which this webhook will be fired.  Valid values are ALERT_OPENED, ALERT_UPDATED, ALERT_RESOLVED, ALERT_MAINTENANCE, ALERT_SNOOZED  # noqa: E501

        :param triggers: The triggers of this Notificant.  # noqa: E501
        :type: list[str]
        """
        if self._configuration.client_side_validation and triggers is None:
            raise ValueError("Invalid value for `triggers`, must not be `None`")  # noqa: E501
        allowed_values = ["ALERT_OPENED", "ALERT_UPDATED", "ALERT_RESOLVED", "ALERT_MAINTENANCE", "ALERT_SNOOZED", "ALERT_INVALID", "ALERT_NO_LONGER_INVALID", "ALERT_TESTING", "ALERT_RETRIGGERED", "ALERT_NO_DATA", "ALERT_NO_DATA_RESOLVED", "ALERT_NO_DATA_MAINTENANCE", "ALERT_SEVERITY_UPDATE"]  # noqa: E501
        if (self._configuration.client_side_validation and
                not set(triggers).issubset(set(allowed_values))):  # noqa: E501
            raise ValueError(
                "Invalid values for `triggers` [{0}], must be a subset of [{1}]"  # noqa: E501
                .format(", ".join(map(str, set(triggers) - set(allowed_values))),  # noqa: E501
                        ", ".join(map(str, allowed_values)))
            )

        self._triggers = triggers

    @property
    def updated_epoch_millis(self):
        """Gets the updated_epoch_millis of this Notificant.  # noqa: E501


        :return: The updated_epoch_millis of this Notificant.  # noqa: E501
        :rtype: int
        """
        return self._updated_epoch_millis

    @updated_epoch_millis.setter
    def updated_epoch_millis(self, updated_epoch_millis):
        """Sets the updated_epoch_millis of this Notificant.


        :param updated_epoch_millis: The updated_epoch_millis of this Notificant.  # noqa: E501
        :type: int
        """

        self._updated_epoch_millis = updated_epoch_millis

    @property
    def updater_id(self):
        """Gets the updater_id of this Notificant.  # noqa: E501


        :return: The updater_id of this Notificant.  # noqa: E501
        :rtype: str
        """
        return self._updater_id

    @updater_id.setter
    def updater_id(self, updater_id):
        """Sets the updater_id of this Notificant.


        :param updater_id: The updater_id of this Notificant.  # noqa: E501
        :type: str
        """

        self._updater_id = updater_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Notificant, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Notificant):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Notificant):
            return True

        return self.to_dict() != other.to_dict()
